@@ -10,28 +10,21 @@ import time
 #!                              !
 #!------------------------------!
 
-lvers = "1.0.9"
+lvers = "1.0.16"
 
 
 def checkver():
-    packagenm = 'ngrok_info'  # replace with the package you want to check
+    packagenm = 'ngrok_info'
     responseinfl = requests.get(f'https://pypi.org/pypi/{packagenm}/json')
     latest_version = responseinfl.json()['info']['version']
     if latest_version != lvers:
-        print("You are not using latest version, run 'python3 -m pip install ngrok_info --upgrade'")
+        print("You are not using latest version, run 'python3 -m pip install --upgrade ngrok_info'")
 
 checkver()
 
 #last line deletion
 def delete_last_line():
-    "Use this function to delete the last line in the STDOUT"
-
-    #cursor up one line
-    sys.stdout.write('\x1b[1A')
-
-    #delete last line
-    sys.stdout.write('\x1b[2K')
-
+    pass
 
 def err_gtngr_do_not_use_for_urself():
     delete_last_line()
@@ -39,11 +32,10 @@ def err_gtngr_do_not_use_for_urself():
 
 def gtngr_do_not_use_for_urself():
     url = "http://localhost:4040/api/tunnels/"
+    tunnel_name = par_tnl
     
 
-    time.sleep(0.01)
     delete_last_line()
-    print('Getting Ngrok stats from tunnel "{}"..'.format(par_tnl))
     try:
         res = requests.get(url)
         res_unicode = res.content.decode("utf-8")
@@ -51,7 +43,6 @@ def gtngr_do_not_use_for_urself():
         for i in res_json["tunnels"]:
             if i['name'] == tunnel_name:
                 delete_last_line()
-                print('Getting Ngrok stats from tunnel "{}"...'.format(par_tnl))
                 return i['public_url']
                 break
     except:
@@ -70,9 +61,8 @@ def get(tnl_nm = "command_line"):
     global par_tnl
     par_tnl = tnl_nm
     err = 0
-    print('Getting Ngrok stats from tunnel "{}".'.format(par_tnl))
+    print('Getting Ngrok stats from tunnel "{}"..'.format(par_tnl))
     ngr = gtngr_do_not_use_for_urself()
-    time.sleep(0.01)
     tcp = 5
     try:
         if ngr.find("tcp://") != -1:
@@ -108,7 +98,6 @@ def get(tnl_nm = "command_line"):
             print("ADRESS:", adress)
             print("IP:    ", ip)
             print("PORT:  ", port)
-            print("")
             
     if tcp == 0:
         try:
